Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 750827968dcd757edff47ece2ed0948930aa688f..ce3c2fc53537f15b2dedd9a2f42e809ccd79ab67 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -952,9 +952,9 @@ class Heap { |
void IterateWeakRoots(ObjectVisitor* v, VisitMode mode); |
// Iterate pointers to from semispace of new space found in memory interval |
- // from start to end. |
- void IterateAndMarkPointersToFromSpace(bool record_slots, Address start, |
- Address end, |
+ // from start to end of |object|. |
Michael Starzinger
2015/08/04 15:20:12
nit: s/of/within/, otherwise it sounds like "end o
Hannes Payer (out of office)
2015/08/04 16:16:21
Done.
|
+ void IterateAndMarkPointersToFromSpace(HeapObject* object, Address start, |
+ Address end, bool record_slots, |
ObjectSlotCallback callback); |
// Returns whether the object resides in new space. |